@@ -39,6 +39,8 @@
 //! Using Optioned for your own types is as simple as implementing `Noned` for
 //! your type, provided that your type is already Copy and Sized.
 
+#![deny(missing_docs)]
+
 use std::slice::Iter;
 use std::cmp::Ordering;
 use std::convert::From;
@@ -685,6 +687,7 @@ impl Debug for OptionBool {
     }
 }
 
+///iterate over an OptionBool
 pub struct IterBool { o: OptionBool }
 
 impl Iterator for IterBool {
@@ -876,6 +879,7 @@ impl Noned for f64 {
 
 ///Equality within Optioned
 pub trait OptEq {
+    /// Is the other optioned equal to this one?
     #[inline]
     fn opt_eq(&self, other: &Self) -> bool;
 }
@@ -905,6 +909,7 @@ impl OptEq for f64 {
 
 ///Ordering within Optioned
 pub trait OptOrd {
+    /// compare this Optioned with another
     #[inline]
     fn opt_cmp(&self, other: &Self) -> Ordering;
 }
@@ -1336,6 +1341,7 @@ impl<T: Noned + Copy> Default for Optioned<T> {
     }
 }
 
+/// iterate over an Optioned<T>
 #[derive(Copy, Clone)]
 pub struct OptionedIter<T: Noned + Copy> { o: Optioned<T> }
 
@@ -1366,44 +1372,3 @@ impl<T: Noned + Copy> Into<Option<T>> for Optioned<T> {
     #[inline]
     fn into(self) -> Option<T> { self.as_option() }
 }
-
-#[test]
-fn into_option_bool() {
-    let optionals = [ OptionBool::some(true), OptionBool::some(false), OptionBool::none() ];
-
-    for o in optionals.iter() {
-        let opt : Option<bool> = o.into();
-        let o2 : OptionBool = opt.into();
-        assert!(o == o2);
-    }
-}
-
-#[test]
-fn test_bool_map() {
-    let optionals =
-        [ OptionBool::SomeTrue, OptionBool::SomeFalse, OptionBool::None ];
-
-    for o in optionals.iter() {
-        assert!(o == o.map_bool(|b| b));
-        let opt : Option<bool> = **o; // double deref for &
-        assert!(opt == o.map(|b| b));
-    }
-
-    assert!(SomeTrue == SomeFalse.map_bool(|b| !b))
-}
-
-#[test]
-fn deref_to_option() {
-    assert!(*OptionBool::some(true) == Option::Some(true));
-    assert!(*OptionBool::some(false) == Option::Some(false));
-    assert!(*OptionBool::none() == Option::None);
-}
-
-#[test]
-fn optioned_is_some_or_none() {
-    let opt_u32 : Optioned<u32> = Optioned::some(32);
-    assert!(opt_u32.is_some());
-
-    let opt_u32_none : Optioned<u32> = Optioned::none();
-    assert!(opt_u32_none.is_none());
-}
